   import React from 'react';
   import {
       Accordion,
       AccordionSummary,
       AccordionDetails,
       Typography,
   } from '@mui/material';
   import ExpandMoreIcon from '@mui/icons-material/ExpandMore';

   const RunDetails: React.FC<RunDetailsProps> = ({ run }) => {
       const { beamline_parameters } = run;
       const { synchrotron, beamline, detector } = beamline_parameters;

       return (
           <div style={{ padding: '16px', border: '1px solid #ccc', borderRadius: '4px' }}>
               <Typography variant="h6" gutterBottom>
                   Run {run.run_number} Details
               </Typography>
               <Typography variant="subtitle1" gutterBottom>
                   Beamline: {beamline} | Synchrotron: {synchrotron}
               </Typography>

               <Accordion>
                   <AccordionSummary
                       expandIcon={<ExpandMoreIcon />}
                       aria-controls="detector-content"
                       id="detector-header"
                   >
                       <Typography><strong>Detector Details</strong></Typography>
                   </AccordionSummary>
                   <AccordionDetails>
                       <Typography>Manufacturer: {detector?.manufacturer || 'N/A'}</Typography>
                       <Typography>Model: {detector?.model || 'N/A'}</Typography>
                       <Typography>Type: {detector?.type || 'N/A'}</Typography>
                       <Typography>
                           Beam Center (px): x: {detector?.beamCenterX_px || 'N/A'}, y: {detector?.beamCenterY_px || 'N/A'}
                       </Typography>
                   </AccordionDetails>
               </Accordion>

               <Accordion>
                 <AccordionSummary
                     expandIcon={<ExpandMoreIcon />}
                     aria-controls="beamline-content"
                     id="beamline-header"
                 >
                   <Typography><strong>Beamline Details</strong></Typography>
                 </AccordionSummary>
                 <AccordionDetails>
                   <Typography>Synchrotron: {beamline_parameters?.synchrotron || 'N/A'}</Typography>
                   <Typography>Ring mode: {beamline_parameters?.ringMode || 'N/A'}</Typography>
                   <Typography>Ring current: {beamline_parameters?.ringCurrent_A || 'N/A'}</Typography>
                   <Typography>Beamline: {beamline_parameters?.beamline || 'N/A'}</Typography>
                   <Typography>Undulator: {beamline_parameters?.undulator || 'N/A'}</Typography>
                   <Typography>Undulator gap: {beamline_parameters?.undulatorgap_mm || 'N/A'}</Typography>
                   <Typography>Focusing optic: {beamline_parameters?.focusingOptic || 'N/A'}</Typography>
                   <Typography>Monochromator: {beamline_parameters?.monochromator || 'N/A'}</Typography>
                 </AccordionDetails>
               </Accordion>

               <Accordion>
                   <AccordionSummary
                       expandIcon={<ExpandMoreIcon />}
                       aria-controls="beam-content"
                       id="beam-header"
                   >
                       <Typography><strong>Beam characteristics</strong></Typography>
                   </AccordionSummary>
                   <AccordionDetails>
                       <Typography>Wavelength: {beamline_parameters?.wavelength || 'N/A'}</Typography>
                       <Typography>Energy: {beamline_parameters?.energy || 'N/A'}</Typography>
                       <Typography>Transmission: {beamline_parameters?.transmission || 'N/A'}</Typography>
                       <Typography>Beam focus (µm): vertical: {beamline_parameters?.beamSizeHeight || 'N/A'} , horizontal: {beamline_parameters?.beamSizeWidth || 'N/A'}</Typography>
                       <Typography>Flux at sample (ph/s): {beamline_parameters?.beamlineFluxAtSample_ph_s || 'N/A'}</Typography>
                   </AccordionDetails>
               </Accordion>

               <Accordion>
                   <AccordionSummary
                       expandIcon={<ExpandMoreIcon />}
                       aria-controls="sample-content"
                       id="sample-header"
                   >
                       <Typography><strong>Sample environment</strong></Typography>
                   </AccordionSummary>
                   <AccordionDetails>
                       <Typography>Cryojet temperature (K): {beamline_parameters?.cryojetTemperature_K || 'N/A'}</Typography>
                       <Typography>Humidifier temperature (K): {beamline_parameters?.humidifierTemperature_K || 'N/A'}</Typography>
                       <Typography>Humidifier humidity (%): {beamline_parameters?.humidifierHumidity || 'N/A'}</Typography>
                   </AccordionDetails>
               </Accordion>

               <Accordion>
                   <AccordionSummary
                       expandIcon={<ExpandMoreIcon />}
                       aria-controls="images-content"
                       id="images-header"
                   >
                       <Typography><strong>Associated Images</strong></Typography>
                   </AccordionSummary>
                   <AccordionDetails>
                       {run.images?.map((img) => (
                           <img
                               key={img.id}
                               src={img.filepath}
                               alt={img.comment || 'Sample Image'}
                               style={{
                                   width: '100%',
                                   border: '1px solid #ccc',
                                   marginTop: 8,
                               }}
                           />
                       )) || 'No Images Available'}
                   </AccordionDetails>
               </Accordion>
           </div>
       );
   };

   export default RunDetails;